/*
 * Example: Dice
 */
package at.ac.wu.ai.java.dice;

import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import javax.swing.*;


public class JDiceComponent extends JComponent {

	final static private int X_SIZE=200;
	final static private int Y_SIZE=200;
	final static private int DICE_POINT_DIAMETER = 30;
	final static private Rectangle2D.Double DICE_FORM = new Rectangle2D.Double(5,5,190,190);
	
	private BufferedImage buffer;
	
	public JDiceComponent() {
		// create buffer
		buffer = new BufferedImage(X_SIZE, Y_SIZE, BufferedImage.TYPE_INT_RGB);
		
		// set object size
		setPreferredSize( new Dimension(X_SIZE, Y_SIZE));
		
		// initialize the dice with a "one"
		paintDice(1);
	}

	protected void paintComponent(Graphics g) {
		super.paintComponent(g);
		// transfer buffer to the screen
		Graphics2D g2d = (Graphics2D)g.create();
		g2d.drawImage(buffer, 0, 0, this);
		g2d.dispose();
	}

	/**
	 * Paint the dice.
	 * <ul>
	 *   <li>erases the buffer </li>
	 *   <li>paint an empty dice</li>
	 *   <li>paint the number corresponding to the dice's value</li>
	 * </ul>
	 */
	public void paintDice(int value) {
		
		assert(value>0 && value<7);
		
		Graphics2D g2d = buffer.createGraphics();
		g2d.clearRect(0, 0, X_SIZE, Y_SIZE);
		g2d.setColor(Color.WHITE);
		g2d.fill( DICE_FORM );
		
		// set the color to black for the dice's points
		g2d.setColor(Color.BLACK);
		switch (value) {
			case 1:	paintOne(g2d); 
					break;
			case 2: paintTwo(g2d);
					break;
			case 3: paintThree(g2d); 
					break;
			case 4: paintFour(g2d); 
					break;
			case 5: paintFive(g2d); 
					break;
			case 6: paintSix(g2d); 
					break;
		}
	}
	
	private void paintOne(Graphics2D g2d) {
		Ellipse2D.Double punkt11 = 
			new Ellipse2D.Double( 100-DICE_POINT_DIAMETER/2, 100-DICE_POINT_DIAMETER/2, DICE_POINT_DIAMETER, DICE_POINT_DIAMETER);
		g2d.fill(punkt11);
	}
	
	private void paintTwo(Graphics2D g2d) {
		Ellipse2D.Double punkt21 =
			new Ellipse2D.Double( 50-DICE_POINT_DIAMETER/2, 50-DICE_POINT_DIAMETER/2, DICE_POINT_DIAMETER, DICE_POINT_DIAMETER);
		Ellipse2D.Double punkt22 =
			new Ellipse2D.Double( 150-DICE_POINT_DIAMETER/2, 150-DICE_POINT_DIAMETER/2, DICE_POINT_DIAMETER, DICE_POINT_DIAMETER);
		g2d.fill(punkt21);
		g2d.fill(punkt22);
	}
	
	private void paintThree(Graphics2D g2d) {
		paintOne(g2d);
		paintTwo(g2d);
	}
	
	private void paintFour(Graphics2D g2d) {
		paintTwo(g2d);
		Ellipse2D.Double punkt43 =
			new Ellipse2D.Double( 50-DICE_POINT_DIAMETER/2, 150-DICE_POINT_DIAMETER/2, DICE_POINT_DIAMETER, DICE_POINT_DIAMETER);
		Ellipse2D.Double punkt44 =
			new Ellipse2D.Double( 150-DICE_POINT_DIAMETER/2, 50-DICE_POINT_DIAMETER/2, DICE_POINT_DIAMETER, DICE_POINT_DIAMETER);
		g2d.fill(punkt43);
		g2d.fill(punkt44);
	}
	
	private void paintFive(Graphics2D g2d) {
		paintFour(g2d);
		paintOne(g2d);
	}
	
	private void paintSix(Graphics2D g2d) {
		paintFour(g2d);
		Ellipse2D.Double punkt65 =
			new Ellipse2D.Double(50-DICE_POINT_DIAMETER/2, 100-DICE_POINT_DIAMETER/2, DICE_POINT_DIAMETER, DICE_POINT_DIAMETER);
		Ellipse2D.Double punkt66 = 
			new Ellipse2D.Double(150-DICE_POINT_DIAMETER/2, 100-DICE_POINT_DIAMETER/2, DICE_POINT_DIAMETER, DICE_POINT_DIAMETER);
		g2d.fill(punkt65);
		g2d.fill(punkt66);
	}

}
